==> haskell-bindings-uname-0.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bindings-uname.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bindings-uname
version:              0.1
visibility:           public
id:                   bindings-uname-0.1-93fUh9ywKaW6aN0xumNgpp
key:                  bindings-uname-0.1-93fUh9ywKaW6aN0xumNgpp
license:              LicenseRef-PublicDomain
maintainer:           PHO <pho at cielonegro.org>
author:               PHO <pho at cielonegro.org>
stability:            Experimental
synopsis:             Low-level binding to POSIX uname(3)
description:
    This is a low-level binding to POSIX uname(3)
    function. Perhaps it shoule be part of unix package.

category:             FFI, System
abi:                  fbfa86ecb1cd7671d66a12f7c0d3837d
exposed:              True
exposed-modules:      Bindings.Uname
import-dirs:          /usr/lib/ghc-8.8.3/site-local/bindings-uname-0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/bindings-uname-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/bindings-uname-0.1
hs-libraries:         HSbindings-uname-0.1-93fUh9ywKaW6aN0xumNgpp
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-bindings-uname/html/bindings-uname.haddock

haddock-html:         /usr/share/doc/haskell-bindings-uname/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bindings-uname-0.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bindings-uname.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bindings-uname
version:              0.1
visibility:           public
id:                   bindings-uname-0.1-HDYlkbBU8Jf9Xq0uZp6pHC
key:                  bindings-uname-0.1-HDYlkbBU8Jf9Xq0uZp6pHC
license:              LicenseRef-PublicDomain
maintainer:           PHO <pho at cielonegro.org>
author:               PHO <pho at cielonegro.org>
stability:            Experimental
synopsis:             Low-level binding to POSIX uname(3)
description:
    This is a low-level binding to POSIX uname(3)
    function. Perhaps it shoule be part of unix package.

category:             FFI, System
abi:                  52f442e60b8b1124c60f3fd11f656bfb
exposed:              True
exposed-modules:      Bindings.Uname
import-dirs:          /usr/lib/ghc-8.10.1/site-local/bindings-uname-0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/bindings-uname-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/bindings-uname-0.1
hs-libraries:         HSbindings-uname-0.1-HDYlkbBU8Jf9Xq0uZp6pHC
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-bindings-uname/html/bindings-uname.haddock

haddock-html:         /usr/share/doc/haskell-bindings-uname/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
